@@ -39,20 +39,25 @@ def create_topic_model(
         """There is a bug with the c_v method this issue has been reported here: https://github.com/bab2min/tomotopy/issues/126"""
         if not cohs_path.exists():
             print("Processing coherence score")
-            coh_u_mass = tp.coherence.Coherence(mdl, coherence="u_mass")
             coh_c_v = tp.coherence.Coherence(mdl, coherence="c_v")
+            coh_u_mass = tp.coherence.Coherence(mdl, coherence="u_mass")
             coh_c_npmi = tp.coherence.Coherence(mdl, coherence="c_npmi")
             topics_coherence = []
-            for topic_num in range[0:num_topics]:
+            for topic_num in range(0, num_topics):
                 topics_coherence.append(
                     [
                         topic_num,
-                        coh_u_mass.get_score(topic_id=topic_num),
                         coh_c_v.get_score(topic_id=topic_num),
+                        coh_u_mass.get_score(topic_id=topic_num),
                         coh_c_npmi.get_score(topic_id=topic_num),
                     ]
                 )
-            dta = pd.DataFrame(topics_coherence, columns=["topic_num", "u_mass", "c_v", "c_npmi"])
+            dta = pd.DataFrame(topics_coherence, columns=["topic_num", "cv", "umass", "npmi"])
+            coh_scores = ["cv", "umass", "npmi"]
+            for coh_score in coh_scores:
+                dta[f"{coh_score}_rank"] = dta[coh_score].rank(method="dense", ascending=False)
+            dta["rank_average"] = dta[["umass_rank", "cv_rank", "npmi_rank"]].mean(axis=1)
+            dta.sort_values(by="rank_average", inplace=True)
             pf.save_dataframe_as_parquet(dta, cohs_path)
             dta.to_excel(cohx_path, index=False)
 
@@ -138,7 +143,7 @@ def create_topic_model(
     target_num_label = f"{target_label}_{str(num_topics).zfill(4)}"
     corp_path = topic_model_path / f"{target_label}_corpus.tomotopy"
     modl_path = topic_model_num_path / f"{target_num_label}_{model_type}_model.modl"
-    cohs_path = topic_model_path / f"{target_label}_{model_type}_model_coherence.parquet"
-    cohx_path = topic_model_path / f"{target_label}_{model_type}_model_coherence.xlsx"
+    cohs_path = topic_model_num_path / f"{target_label}_{model_type}_model_topics_coherence.parquet"
+    cohx_path = topic_model_num_path / f"{target_label}_{model_type}_model_topics_coherence.xlsx"
     topic_model_num_path.mkdir(parents=True, exist_ok=True)
-    create_model(modl_path, corp_path, cohs_path, cohx_path, num_topics, alpha, eta, term_weight)
+    create_model(modl_path, corp_path, cohs_path, cohx_path, num_topics, term_weight, alpha, eta)
